PRO PolyShapeOnMap, PS=ps

    ; The name of the shapefile from which the polygon is extracted.
    shapefile = 'C:\IDL\data\shapefiles\COUNTIES.shp'
    
    ; Set up a map projection coordinate object for the shape polygon.
    utmMap = Obj_New('cgMap', 'UTM', ELLIPSOID='GRS 1980', ZONE=13)
    
    ; Set up variables for the Google Map.
    centerLat = 39.5
    centerLon = -106.0
    zoom = 9
    scale = cgGoogle_MetersPerPixel(zoom)
    xsize = 600 < 640 ; Max size of Google image with this Google API
    ysize = 600 < 640 ; Max size of Google image with this Google API
    resolution = StrTrim(xsize,2) + 'x' + StrTrim(ysize,2)
    
    ; Get the Google Map image.
    googleStr = "http://maps.googleapis.com/maps/api/staticmap?" + $
        "center=" + StrTrim(centerLat,2) + ',' + StrTrim(centerLon,2) + $
        "&zoom=" + StrTrim(zoom,2) + "&size=" + resolution + $
        "&maptype=terrain&sensor=false&format=png32"
    netObject = Obj_New('IDLnetURL')
    void = netObject -> Get(URL=googleStr, FILENAME="googlemapimg.png")
    Obj_Destroy, netObject
    googleMapImage = Read_Image('googlemapimg.png')
    
    ; Set up a map coordinate object that fits the Google map.
    googleMap = Obj_New('cgMap', 'Mercator', ELLIPSOID='WGS 84')
    uv = googleMap -> Forward(centerLon, centerLat)
    uv_xcenter = uv[0,0]
    uv_ycenter = uv[1,0]
    xrange = [uv_xcenter - (xsize/2.0D*scale), uv_xcenter + (xsize/2.0D*scale)]
    yrange = [uv_ycenter - (ysize/2.0D*scale), uv_ycenter + (ysize/2.0D*scale)]
    googleMap -> SetProperty, XRANGE=xrange, YRANGE=yrange

    ; Create a display window. Make this is pixmap window if you are creating
    ; a PostScript or raster file.
    cgDisplay, 700, 700, Aspect=googleMapImage, /Free, Pixmap=Keyword_Set(ps)
    
    ; Display the image and take a picture of it for the background image.
    cgImage, googleMapImage[0:2,*,*], Position=[50, 50, 650, 650]/700.0, $
        /Keep_Aspect, OPosition=outputPosition
    googleMap -> SetProperty, Position=outputPostion
    backgroundImage = cgSnapshot()
    
    ; Draw the polygon on the map and take a picture of the display for the 
    ; foreground image.
    cgDrawShapes, shapefile, MapCoord=utmMap, DrawMapCoord=googleMap, $
          ATTRName='COUNTY', ATTRValue='SUMMIT', $
         /Projected_XY, Color='red', Thick=4
    cgDrawShapes, shapefile, MapCoord=utmMap, DrawMapCoord=googleMap, $
        ATTRName='COUNTY', ATTRValue='SUMMIT', $
         /Projected_XY, /Fill, FColor='orange'
    foregroundImage = cgSnapshot()
    
    ; Open a PostScript file, if needed.
    IF Keyword_Set(ps) THEN cgPS_Open, 'summit.ps'
    
    ; Display the blended transparent image.
    cgBlendImage, foregroundImage, backgroundImage, Alpha=0.3, $
        Position=[0.0, 0.0, 1.0, 1.0]
    
    ; Add whatever map annotations you need.
    cgMap_Grid, Map=googleMap, /Box_Axes, /cgGrid, Format='(F0.2)'
    
    ; Clean up if necessary. Make a PNG file from the PostScript file.
    IF Keyword_Set(ps) THEN BEGIN
       cgPS_Close, /PNG
       WDelete, !D.Window
    ENDIF

END